"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const ts_eslint_1 = require("@typescript-eslint/utils/dist/ts-eslint");
const handleQueryError_1 = __importDefault(require("../../rules/handleQueryError"));
const ruleTester = new ts_eslint_1.RuleTester({
    parser: require.resolve('@typescript-eslint/parser'),
});
ruleTester.run('handle-query-error', handleQueryError_1.default, {
    valid: [
        {
            code: `const { data, error, loading } = useQuery<CheckoutQueryResultData>(
                    checkoutQuery,
                    {
                        variables: {
                            store,
                            language,
                            cartType,
                        },
                        pollInterval: 30_000,
                        fetchPolicy: 'network-only',
                        notifyOnNetworkStatusChange: true,
                        onCompleted: () => {
                            onCompleted();
                            if (!initialized) {
                                setInitialized(true);
                            }
                        },
                    }
                );
            `,
        },
        {
            code: `const [runQuery, { error, loading }] = useLazyQuery<CheckoutQueryResultData>(
                    checkoutQuery,
                    {
                        variables: {
                            store,
                            language,
                            cartType,
                        },
                        pollInterval: 30_000,
                        fetchPolicy: 'network-only',
                        notifyOnNetworkStatusChange: true,
                        onCompleted: () => {
                            onCompleted();
                            if (!initialized) {
                                setInitialized(true);
                            }
                        },
                    }
                );
            `,
        },
        {
            code: `const { data, loading } = useProductsQueryFilters<CheckoutQueryResultData>(
                    checkoutQuery,
                    {
                        variables: {
                            store,
                            language,
                            cartType,
                        },
                        pollInterval: 30_000,
                        fetchPolicy: 'network-only',
                        notifyOnNetworkStatusChange: true,
                        onCompleted: () => {
                            onCompleted();
                            if (!initialized) {
                                setInitialized(true);
                            }
                        },
                    }
                );
            `,
        },
        {
            code: `const { data, loading } = useQuery<CheckoutQueryResultData>(
                    checkoutQuery,
                    {
                        variables: {
                            store,
                            language,
                            cartType,
                        },
                        pollInterval: 30_000,
                        fetchPolicy: 'network-only',
                        notifyOnNetworkStatusChange: true,
                        onCompleted: () => {
                            onCompleted();
                            if (!initialized) {
                                setInitialized(true);
                            }
                        },
                    }
                );
            `,
            options: [{ ignoreHooks: ['useQuery'] }],
        },
    ],
    invalid: [
        {
            code: `const { data, loading } = useQuery<CheckoutQueryResultData>(
                    checkoutQuery,
                    {
                        variables: {
                            store,
                            language,
                            cartType,
                        },
                        pollInterval: 30_000,
                        fetchPolicy: 'network-only',
                        notifyOnNetworkStatusChange: true,
                        onCompleted: () => {
                            onCompleted();
                            if (!initialized) {
                                setInitialized(true);
                            }
                        },
                    }
                );
            `,
            errors: [{ messageId: 'general' }],
        },
        {
            code: `const [runQuery, { loading }] = useLazyQuery<CheckoutQueryResultData>(
                    checkoutQuery,
                    {
                        variables: {
                            store,
                            language,
                            cartType,
                        },
                        pollInterval: 30_000,
                        fetchPolicy: 'network-only',
                        notifyOnNetworkStatusChange: true,
                        onCompleted: () => {
                            onCompleted();
                            if (!initialized) {
                                setInitialized(true);
                            }
                        },
                    }
                );
            `,
            errors: [{ messageId: 'lazyQuery' }],
        },
        {
            code: `const [runQuery] = useLazyQuery<CheckoutQueryResultData>(
                    checkoutQuery,
                    {
                        variables: {
                            store,
                            language,
                            cartType,
                        },
                        pollInterval: 30_000,
                        fetchPolicy: 'network-only',
                        notifyOnNetworkStatusChange: true,
                        onCompleted: () => {
                            onCompleted();
                            if (!initialized) {
                                setInitialized(true);
                            }
                        },
                    }
                );
            `,
            errors: [{ messageId: 'lazyQuery' }],
        },
    ],
});
